@@ -61,6 +61,13 @@ def create_project(project_name):
 
     df_5.to_excel(writer, sheet_name = '5_quality_filtering', index = False)
 
+    ## write the 6_dereplication_pooling sheet
+    df_6 = pd.DataFrame([[5]],
+                        columns = ["min size to pool"])
+
+    df_6.to_excel(writer, sheet_name = '6_dereplication_pooling', index = False)
+
+
     ## write the 7_otu_clustering sheet
     df_7 = pd.DataFrame([[97]],
                         columns = ['pct id'])
